import { SvelteComponentTyped } from 'svelte';

export declare const createModal: (target: HTMLDivElement | HTMLElement, url: string) => SvelteComponentTyped;

export declare const createSberIdIFrame: (environment: Environment) => {
    open: (SberIdResponse: SberIdResponseParams) => Promise<unknown>;
};

/**
 * Creates a payment widget
 *
 * @param
 * environment - 'localhost', 'IFT', 'UAT', 'PRODUCTION'
 */
export declare const createWidget: (environment: "localhostHttps" | "localhost" | "IFT" | "UAT" | "PRODUCTION", isInHouse?: boolean) => Widget;

export declare const createWidgetInternal: (environment: Environment, isInHouse?: boolean) => Widget;

declare type Environment = keyof typeof targets;

export declare type SberIdResponseParams = {
    status: string;
    authCode?: string;
    state?: string;
};

declare const targets: {
    readonly localhostHttps: "https://localhost:3000";
    readonly localhost: "http://localhost:3000";
    readonly IFT: "https://ift.platiecom.ru";
    readonly UAT: "https://psi.platiecom.ru";
    readonly PRODUCTION: "https://platiecom.ru";
};

export declare type Widget = {
    /**
     * Method that opens the widget
     *
     * @param
     * params - widget parameters
     */
    open: (params: WidgetParams) => Promise<"success" | "return" | "cancel">;
    /**
     * Method that close the widget on desktop
     *
     */
    close?: () => void;
};

export declare type WidgetParams = {
    bankInvoiceId: string;
    lifeTime?: number;
    expirationDate?: number;
    backUrl: string;
};

export { }
